==> mingw-w64-starship-1.17.1-2.src.tar.zst: starship-1.17.1/docs/fr-FR/presets/README.md <==
# Préréglages

Voici un ensemble de préréglages pour Starship soumis par la communauté. Si vous avez un préréglage à partager, veuillez [proposer une PR](https://github.com/starship/starship/edit/master/docs/presets/README.md) pour mettre à jour ce fichier! 😊

Pour obtenir des détails sur comment utiliser un préréglage, cliquez simplement sur l’image.

## [Symboles Nerd Font](./nerd-font.md)

Ce préréglage change les symboles de chaque module pour utiliser les symboles de Nerd Font.

[![Capture d'écran du préréglage Nerd Font Symbols](/presets/img/nerd-font-symbols.png "Cliquez pour voir le préréglage Nerd Font Symbols")](./nerd-font)

## [No Nerd Fonts](./no-nerd-font.md)

This preset changes the symbols for several modules so that no Nerd Font symbols are used anywhere in the prompt.

::: tip

This preset will become the default preset [in a future release of starship](https://github.com/starship/starship/pull/3544).

:::

[Click to view No Nerd Font preset](./no-nerd-font)

## [Segments entre crochets](./bracketed-segments.md)

Ce préréglage modifie le format de tous les modules intégrés pour afficher leur segment entre crochets au lieu d'utiliser les labels par défaut de Starship ("via", "on", etc.).

[![Capture d'écran du préréglages Segments entre crochets](/presets/img/bracketed-segments.png "Cliquez pour voir le préréglage Segments entre crochets")](./bracketed-segments)

## [Texte uniquement](./plain-text.md)

Ce préréglage change les symboles de chaque module en texte brut. Idéal si vous n'avez pas accès à Unicode.

[![Capture d'écran du préréglage Texte uniquement](/presets/img/plain-text-symbols.png "Cliquez pour voir le préréglage Texte uniquement")](./plain-text)

## [Pas de version des environnements](./no-runtimes.md)

Ce préréglage masque la version des environnements. Si vous travaillez dans des conteneurs ou environnements virtuels, celui-là est pour vous!

[![Capture d'écran du préréglage Pas de version des environnements](/presets/img/no-runtime-versions.png "Cliquez pour voir le préréglage Pas de version des environnements")](./no-runtimes)

## [No Empty Icons](./no-empty-icons.md)

This preset does not show icons if the toolset is not found.

[![Screenshot of No Empty Icons preset](/presets/img/no-empty-icons.png "Cliquez pour voir le préréglage Pas de version des environnements")](./no-empty-icons.md)

## [Invite de commande Pure](./pure-preset.md)

Ce préréglage émule l'apparence et le comportement de [Pure](https://github.com/sindresorhus/pure).

[![Capture d'écran du préréglage Pure](/presets/img/pure-preset.png "Cliquez pour voir le préréglage Pure")](./pure-preset)

## [Pastel Powerline](./pastel-powerline.md)

Ce préréglage s'inspire de [M365Princess](https://github.com/JanDeDobbeleer/oh-my-posh/blob/main/themes/M365Princess.omp.json). Il montre également comment fonctionne la substitution de chemin dans starship.

[![Capture d'écran du préréglage Pastel Powerline](/presets/img/pastel-powerline.png "Cliquez pour voir le préréglage Pure")](./pastel-powerline)

## [Tokyo Night](./tokyo-night.md)

This preset is inspired by [tokyo-night-vscode-theme](https://github.com/enkia/tokyo-night-vscode-theme).

[![Screenshot of Tokyo Night preset](/presets/img/tokyo-night.png "Click to view Tokyo Night preset")](./tokyo-night)

## [Gruvbox Rainbow](./gruvbox-rainbow.md)

This preset is heavily inspired by [Pastel Powerline](./pastel-powerline.md), and [Tokyo Night](./tokyo-night.md).

[![Screenshot of Gruvbox Rainbow preset](/presets/img/gruvbox-rainbow.png "Click to view Gruvbox Rainbow preset")](./gruvbox-rainbow)

==> mingw-w64-starship-1.24.0-1.src.tar.zst: starship-1.24.0/docs/fr-FR/presets/README.md <==
# Préréglages

Voici un ensemble de préréglages pour Starship soumis par la communauté. Si vous avez un préréglage à partager, veuillez [proposer une PR](https://github.com/starship/starship/edit/master/docs/presets/README.md) pour mettre à jour ce fichier! 😊

Pour obtenir des détails sur comment utiliser un préréglage, cliquez simplement sur l’image.

## [Symboles Nerd Font](./nerd-font.md)

Ce préréglage change les symboles de chaque module pour utiliser les symboles de Nerd Font.

[![Capture d'écran du préréglage Nerd Font Symbols](/presets/img/nerd-font-symbols.png "Cliquez pour voir le préréglage Nerd Font Symbols")](./nerd-font)

## [No Nerd Fonts](./no-nerd-font.md)

This preset changes the symbols for several modules so that no Nerd Font symbols are used anywhere in the prompt.

::: tip

This preset will become the default preset [in a future release of starship](https://github.com/starship/starship/pull/3544).

:::

[Click to view No Nerd Font preset](./no-nerd-font)

## [Segments entre crochets](./bracketed-segments.md)

Ce préréglage modifie le format de tous les modules intégrés pour afficher leur segment entre crochets au lieu d'utiliser les labels par défaut de Starship ("via", "on", etc.).

[![Capture d'écran du préréglages Segments entre crochets](/presets/img/bracketed-segments.png "Cliquez pour voir le préréglage Segments entre crochets")](./bracketed-segments)

## [Texte uniquement](./plain-text.md)

Ce préréglage change les symboles de chaque module en texte brut. Idéal si vous n'avez pas accès à Unicode.

[![Capture d'écran du préréglage Texte uniquement](/presets/img/plain-text-symbols.png "Cliquez pour voir le préréglage Texte uniquement")](./plain-text)

## [Pas de version des environnements](./no-runtimes.md)

Ce préréglage masque la version des environnements. Si vous travaillez dans des conteneurs ou environnements virtuels, celui-là est pour vous!

[![Capture d'écran du préréglage Pas de version des environnements](/presets/img/no-runtime-versions.png "Cliquez pour voir le préréglage Pas de version des environnements")](./no-runtimes)

## [No Empty Icons](./no-empty-icons.md)

This preset does not show icons if the toolset is not found.

[![Screenshot of No Empty Icons preset](/presets/img/no-empty-icons.png "Cliquez pour voir le préréglage Pas de version des environnements")](./no-empty-icons.md)

## [Invite de commande Pure](./pure-preset.md)

Ce préréglage émule l'apparence et le comportement de [Pure](https://github.com/sindresorhus/pure).

[![Capture d'écran du préréglage Pure](/presets/img/pure-preset.png "Cliquez pour voir le préréglage Pure")](./pure-preset)

## [Pastel Powerline](./pastel-powerline.md)

Ce préréglage s'inspire de [M365Princess](https://github.com/JanDeDobbeleer/oh-my-posh/blob/main/themes/M365Princess.omp.json). Il montre également comment fonctionne la substitution de chemin dans starship.

[![Capture d'écran du préréglage Pastel Powerline](/presets/img/pastel-powerline.png "Cliquez pour voir le préréglage Pure")](./pastel-powerline)

## [Tokyo Night](./tokyo-night.md)

This preset is inspired by [tokyo-night-vscode-theme](https://github.com/enkia/tokyo-night-vscode-theme).

[![Screenshot of Tokyo Night preset](/presets/img/tokyo-night.png "Click to view Tokyo Night preset")](./tokyo-night)

## [Gruvbox Rainbow](./gruvbox-rainbow.md)

This preset is heavily inspired by [Pastel Powerline](./pastel-powerline.md), and [Tokyo Night](./tokyo-night.md).

[![Screenshot of Gruvbox Rainbow preset](/presets/img/gruvbox-rainbow.png "Click to view Gruvbox Rainbow preset")](./gruvbox-rainbow)

## [Jetpack](./jetpack.md)

This is a pseudo minimalist preset inspired by the [geometry](https://github.com/geometry-zsh/geometry) and [spaceship](https://github.com/spaceship-prompt/spaceship-prompt) prompts.

[![Screenshot of Jetpack preset](/presets/img/jetpack.png "Click to view Jetpack preset")](./jetpack)

## [Catppuccin Powerline](./catppuccin-powerline.md)

This preset is a minimally modified version of [Gruvbox Rainbow](./gruvbox-rainbow.md) using the [Catppuccin](https://github.com/catppuccin/catppuccin) theme palette.

[![Screenshot of Catppuccin Powerline preset](/presets/img/catppuccin-powerline.png "Click to view Catppuccin Powerline preset")](./catppuccin-powerline)
